@@ -329,6 +329,11 @@ class ControllerApplication(zigpy.application.ControllerApplication):
         await self._znp.nvram_write(NwkNvIds.SRC_RTG_EXPIRY_TIME, t.uint8_t(255))
         await self._znp.nvram_write(NwkNvIds.NWK_CHILD_AGE_ENABLE, t.Bool(False))
 
+        # XXX: the undocumented `znpBasicCfg` request can do this
+        await self._znp.nvram_write(
+            NwkNvIds.LOGICAL_TYPE, t.DeviceLogicalType.Coordinator
+        )
+
         # Reset to make the above NVRAM writes take effect.
         # This also ensures any previously-started network joins don't continue.
         await self._reset()
@@ -352,7 +357,7 @@ class ControllerApplication(zigpy.application.ControllerApplication):
             dbm = self.config[conf.CONF_ZNP_CONFIG][conf.CONF_TX_POWER]
 
             await self._znp.request(
-                c.Sys.SetTxPower.Req(TXPower=dbm), RspStatus=t.Status.SUCCESS
+                c.SYS.SetTxPower.Req(TXPower=dbm), RspStatus=t.Status.SUCCESS
             )
 
         device_info = await self._znp.request(
@@ -471,8 +476,8 @@ class ControllerApplication(zigpy.application.ControllerApplication):
 
     async def _reset(self):
         await self._znp.request_callback_rsp(
-            request=c.Sys.ResetReq.Req(Type=t.ResetType.Soft),
-            callback=c.Sys.ResetInd.Callback(partial=True),
+            request=c.SYS.ResetReq.Req(Type=t.ResetType.Soft),
+            callback=c.SYS.ResetInd.Callback(partial=True),
         )
 
     async def form_network(self):
@@ -481,11 +486,6 @@ class ControllerApplication(zigpy.application.ControllerApplication):
             NwkNvIds.STARTUP_OPTION, t.StartupOptions.ClearState
         )
 
-        # XXX: the undocumented `znpBasicCfg` request can do this
-        await self._znp.nvram_write(
-            NwkNvIds.LOGICAL_TYPE, t.DeviceLogicalType.Coordinator
-        )
-
         pan_id = self.config[conf.CONF_NWK][conf.CONF_NWK_PAN_ID]
         extended_pan_id = self.config[conf.CONF_NWK][conf.CONF_NWK_EXTENDED_PAN_ID]
 
@@ -518,17 +518,10 @@ class ControllerApplication(zigpy.application.ControllerApplication):
             c.ZDO.StateChangeInd.Callback(State=t.DeviceState.StartedAsCoordinator)
         )
 
-        await self._znp.request(
-            c.AppConfig.BDBStartCommissioning.Req(
-                Mode=c.app_config.BDBCommissioningMode.NwkSteering
-            ),
-            RspStatus=t.Status.SUCCESS,
-        )
-
         # Create the NV item that keeps track of whether or not we're configured
         osal_create_rsp = await self._znp.request(
-            c.Sys.OSALNVItemInit.Req(
-                Id=NwkNvIds.HAS_CONFIGURED_ZSTACK3, ItemLen=1, Value=b""
+            c.SYS.OSALNVItemInit.Req(
+                Id=NwkNvIds.HAS_CONFIGURED_ZSTACK3, ItemLen=1, Value=b"\x55"
             )
         )
 
